==> gmt-6.0.0rc2-src.tar.gz: gmt-6.0.0rc2/AUTHORS.md <==
# The Founders

GMT was conceived and designed in the late 1980s and early 1990s
by [Paul Wessel](http://www.soest.hawaii.edu/pwessel/), and
[Walter H.F. Smith](https://www.star.nesdis.noaa.gov/star/Smith_WHF.php).
The two founders built and maintained GMT from version 1 through 3.

# Addition of Team Members

GMT 4 benefitted from numerous contributions from two new team members
[Remko Scharroo](https://www.researchgate.net/profile/Remko_Scharroo)
and [Joaquim Luis](http://w3.ualg.pt/~jluis/).

GMT 5 saw major new contributions from team member Florian Wobbe.

GMT 6 has benefitted from the contributions of two new team members
[Leonardo Uieda](https://www.leouieda.com) and
[Dongdong Tian](https://msu.edu/~tiandong/).

# Supplement Contributions

[Tim Henstock](https://www.southampton.ac.uk/oes/research/staff/then.page)
contributed the segy supplement, while
[Kurt Feigl](http://geoscience.wisc.edu/geoscience/people/faculty/feigl/) and
Genevieve Patau wrote the seis supplement.
[Dennis Milbert](https://geodesyworld.github.io) donated the Fortran code that
was translated to become earthtide.c 
[David Sandwell](https://topex.ucsd.edu/sandwell/) contributed the img supplement.

# Further Acknowledgments

We would also like to acknowledge feedback, suggestions and bug reports
from Andreas Bjørnestad, Michael Barck, Manfred Brands, Allen Cogbill, Stephan Eickschen, John Helly,
Ben Horner-Johnson, Kristof Koch, John Kuhn, Angel Li, Andrew Macrae, Alex Madon, Ken McLean,
Greg Neumann, Ameet Raval, John Robbins, Georg Schwarz, Richard Signell, Peter Schmidt,
Dirk Stoecker, Eduardo Suárez, Mikhail Tchernychev, Malte Thoma, David Townsend,
Garry Vaughan, William Weibel, and many others, including their advice on how
to make GMT portable to a wide range of platforms. John Lillibridge and Stephan
Eickschen provided the original Examples (11) and (32), respectively; Hanno von
Lom helped resolve early problems with DLL libraries for Win32; Lloyd Parkes
enabled indexed color images in PostScript; Brent Wood developed the GMT/OGR format;
Wayne Wilson implemented the full general perspective projection; and William Yip
helped translate GMT to POSIX ANSI C and incorporate netCDF 3. The SOEST RCF staff
(Ross Ishida, Pat Townsend, and Sharon Stahl) provided valuable help on Linux and
web server support.

==> gmt-6.2.0-1.src.tar.gz: gmt-6.2.0/AUTHORS.md <==
# The Founders

GMT was conceived and designed in the late 1980s and early 1990s
by [Paul Wessel](http://www.soest.hawaii.edu/pwessel/) and
[Walter H.F. Smith](https://www.star.nesdis.noaa.gov/star/Smith_WHF.php).
The two founders built and maintained GMT from version 1 through 3.

# Addition of Team Members

GMT 4 benefitted from numerous contributions from two new team members
[Remko Scharroo](https://www.researchgate.net/profile/Remko_Scharroo)
and [Joaquim Luis](http://joa-quim.pt/).

GMT 5 saw major new contributions from team member Florian Wobbe.

GMT 6 has benefitted from the contributions of two new team members
[Leonardo Uieda](https://www.leouieda.com) and
[Dongdong Tian](https://msu.edu/~tiandong/).

# Supplement Contributions

[Tim Henstock](https://www.southampton.ac.uk/oes/research/staff/then.page)
contributed the segy supplement, while
[Kurt Feigl](http://geoscience.wisc.edu/geoscience/people/faculty/feigl/) and
Genevieve Patau wrote the seis supplement.
[Dennis Milbert](https://geodesyworld.github.io) donated the Fortran code that
was translated to become earthtide.c.
[David Sandwell](https://topex.ucsd.edu/sandwell/) contributed the img supplement.

# Further Acknowledgments

We would also like to acknowledge feedback, suggestions and bug reports
from Andreas Bjørnestad, Michael Barck, Manfred Brands, Allen Cogbill, Stephan Eickschen, John Helly,
Ben Horner-Johnson, Kristof Koch, John Kuhn, Angel Li, Andrew Macrae, Alex Madon, Ken McLean,
Greg Neumann, Ameet Raval, John Robbins, Georg Schwarz, Richard Signell, Peter Schmidt,
Dirk Stoecker, Eduardo Suárez, Mikhail Tchernychev, Malte Thoma, David Townsend,
Garry Vaughan, William Weibel, and many others, including their advice on how
to make GMT portable to a wide range of platforms. John Lillibridge and Stephan
Eickschen provided the original Examples (11) and (32), respectively; Hanno von
Lom helped resolve early problems with DLL libraries for Win32; Lloyd Parkes
enabled indexed color images in PostScript; Brent Wood developed the GMT/OGR format;
Wayne Wilson implemented the full general perspective projection; and William Yip
helped translate GMT to POSIX ANSI C and incorporate netCDF 3. The SOEST RCF staff
(Ross Ishida, Pat Townsend, and Sharon Stahl) provided valuable help on Linux and
web server support.
